summaryrefslogtreecommitdiff
path: root/bfd/elf32-d10v.c
diff options
context:
space:
mode:
authorAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:27 +0000
committerAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:27 +0000
commitd9ec26b6578cfde9d7fb605787c9878ccd623893 (patch)
tree20a6a8bcbbf4b7822c06138f1ea37e335a09d5be /bfd/elf32-d10v.c
parent0a693b807e2990a20fcdc75692dd1f1ecd355be0 (diff)
downloadbinutils-redhat-d9ec26b6578cfde9d7fb605787c9878ccd623893.tar.gz
Correct spelling of "relocatable".
Diffstat (limited to 'bfd/elf32-d10v.c')
-rw-r--r--bfd/elf32-d10v.c9
1 files changed, 5 insertions, 4 deletions
diff --git a/bfd/elf32-d10v.c b/bfd/elf32-d10v.c
index 1d6912a0f4..cc5eddce7f 100644
--- a/bfd/elf32-d10v.c
+++ b/bfd/elf32-d10v.c
@@ -1,5 +1,6 @@
/* D10V-specific support for 32-bit ELF
- Copyright 1996, 1998, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+ Copyright 1996, 1998, 1999, 2000, 2001, 2002, 2003
+ Free Software Foundation, Inc.
Contributed by Martin Hunt (hunt@cygnus.com).
This file is part of BFD, the Binary File Descriptor library.
@@ -303,7 +304,7 @@ elf32_d10v_check_relocs (abfd, info, sec, relocs)
const Elf_Internal_Rela *rel;
const Elf_Internal_Rela *rel_end;
- if (info->relocateable)
+ if (info->relocatable)
return TRUE;
symtab_hdr = &elf_tdata (abfd)->symtab_hdr;
@@ -388,9 +389,9 @@ elf32_d10v_relocate_section (output_bfd, info, input_bfd, input_section,
howto = elf_d10v_howto_table + r_type;
- if (info->relocateable)
+ if (info->relocatable)
{
/* This is a relocateable link. We don't have to change
anything, unless the reloc is against a section symbol,
in which case we have to adjust according to where the
section symbol winds up in the output section. */
@@ -388,9 +389,9 @@ elf32_d10v_relocate_section (output_bfd, info, input_bfd, input_section,
{
- /* This is a relocateable link. We don't have to change
+ /* This is a relocatable link. We don't have to change
anything, unless the reloc is against a section symbol,
in which case we have to adjust according to where the